import { __decorate } from 'tslib';
import { ElementRef, Input, HostListener, Directive, NgModule } from '@angular/core';

let NgxPatternDirective = class NgxPatternDirective {
    constructor(host) {
        this.host = host;
    }
    ngOnChanges(changes) {
        if (this.ngxPattern) {
            if (typeof this.ngxPattern === 'string') {
                this.regex = new RegExp(`^${this.ngxPattern}$`, 'g');
            }
            else {
                this.regex = this.ngxPattern;
            }
        }
    }
    onKeyPress(e) {
        if (this.regex && !e.ctrlKey && !isSpecialKey(e.key)) {
            if (!this.validWithChange(e.key)) {
                e.preventDefault();
            }
        }
    }
    onPaste(e) {
        const pastedInput = e.clipboardData.getData('text/plain');
        if (!this.validWithChange(pastedInput)) {
            e.preventDefault();
        }
    }
    onDrop(e) {
        const textData = e.dataTransfer.getData('text');
        if (!this.validWithChange(textData)) {
            e.preventDefault();
        }
    }
    validWithChange(delta) {
        const { value: current, selectionStart, selectionEnd, } = this.inputEl;
        const updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
        const result = !updated || this.regex.test(updated);
        this.regex.lastIndex = 0;
        return result;
    }
    get inputEl() {
        return this.host.nativeElement;
    }
};
NgxPatternDirective.ctorParameters = () => [
    { type: ElementRef }
];
__decorate([
    Input()
], NgxPatternDirective.prototype, "ngxPattern", void 0);
__decorate([
    HostListener('keydown', ['$event'])
], NgxPatternDirective.prototype, "onKeyPress", null);
__decorate([
    HostListener('paste', ['$event'])
], NgxPatternDirective.prototype, "onPaste", null);
__decorate([
    HostListener('drop', ['$event'])
], NgxPatternDirective.prototype, "onDrop", null);
NgxPatternDirective = __decorate([
    Directive({
        selector: '[ngxPattern]'
    })
], NgxPatternDirective);
/** @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values */
function isSpecialKey(key) {
    return key.length > 1;
}

let NgxPatternModule = class NgxPatternModule {
};
NgxPatternModule = __decorate([
    NgModule({
        declarations: [NgxPatternDirective],
        imports: [],
        exports: [
            NgxPatternDirective
        ]
    })
], NgxPatternModule);

/*
 * Public API Surface of ngx-pattern
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxPatternDirective, NgxPatternModule };
//# sourceMappingURL=ngx-pattern.js.map
