import { __decorate } from 'tslib';
import { ElementRef, Input, HostListener, Directive, NgModule } from '@angular/core';

var NgxPatternDirective = /** @class */ (function () {
    function NgxPatternDirective(host) {
        this.host = host;
    }
    NgxPatternDirective.prototype.ngOnChanges = function (changes) {
        if (this.ngxPattern) {
            if (typeof this.ngxPattern === 'string') {
                this.regex = new RegExp("^" + this.ngxPattern + "$", 'g');
            }
            else {
                this.regex = this.ngxPattern;
            }
        }
    };
    NgxPatternDirective.prototype.onKeyPress = function (e) {
        if (this.regex && !e.ctrlKey && !isSpecialKey(e.key)) {
            if (!this.validWithChange(e.key)) {
                e.preventDefault();
            }
        }
    };
    NgxPatternDirective.prototype.onPaste = function (e) {
        var pastedInput = e.clipboardData.getData('text/plain');
        if (!this.validWithChange(pastedInput)) {
            e.preventDefault();
        }
    };
    NgxPatternDirective.prototype.onDrop = function (e) {
        var textData = e.dataTransfer.getData('text');
        if (!this.validWithChange(textData)) {
            e.preventDefault();
        }
    };
    NgxPatternDirective.prototype.validWithChange = function (delta) {
        var _a = this.inputEl, current = _a.value, selectionStart = _a.selectionStart, selectionEnd = _a.selectionEnd;
        var updated = current.substring(0, selectionStart) + delta + current.substring(selectionEnd + 1);
        var result = !updated || this.regex.test(updated);
        this.regex.lastIndex = 0;
        return result;
    };
    Object.defineProperty(NgxPatternDirective.prototype, "inputEl", {
        get: function () {
            return this.host.nativeElement;
        },
        enumerable: true,
        configurable: true
    });
    NgxPatternDirective.ctorParameters = function () { return [
        { type: ElementRef }
    ]; };
    __decorate([
        Input()
    ], NgxPatternDirective.prototype, "ngxPattern", void 0);
    __decorate([
        HostListener('keydown', ['$event'])
    ], NgxPatternDirective.prototype, "onKeyPress", null);
    __decorate([
        HostListener('paste', ['$event'])
    ], NgxPatternDirective.prototype, "onPaste", null);
    __decorate([
        HostListener('drop', ['$event'])
    ], NgxPatternDirective.prototype, "onDrop", null);
    NgxPatternDirective = __decorate([
        Directive({
            selector: '[ngxPattern]'
        })
    ], NgxPatternDirective);
    return NgxPatternDirective;
}());
/** @see https://developer.mozilla.org/bg/docs/Web/API/KeyboardEvent/key/Key_Values */
function isSpecialKey(key) {
    return key.length > 1;
}

var NgxPatternModule = /** @class */ (function () {
    function NgxPatternModule() {
    }
    NgxPatternModule = __decorate([
        NgModule({
            declarations: [NgxPatternDirective],
            imports: [],
            exports: [
                NgxPatternDirective
            ]
        })
    ], NgxPatternModule);
    return NgxPatternModule;
}());

/*
 * Public API Surface of ngx-pattern
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxPatternDirective, NgxPatternModule };
//# sourceMappingURL=ngx-pattern.js.map
